@@ -1557,69 +1557,10 @@ ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
                 if ( ( aValue >>= bPassWord ) && bPassWord )
                 {
                     // ask for a password
-                    uno::Reference < ::com::sun::star::task::XInteractionHandler > xInteractionHandler( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.uui.UUIInteractionHandler"))), UNO_QUERY );
-
-                    if( xInteractionHandler.is() )
-                    {
-                        // TODO: need a save way to distinguish MS filters from other filters
-                        // for now MS-filters are the only alien filters that support encryption
-                        sal_Bool bMSType = !pCurrentFilter->IsOwnFormat();
-                        ::comphelper::DocPasswordRequestType eType = bMSType ?
-                            ::comphelper::DocPasswordRequestType_MS :
-                            ::comphelper::DocPasswordRequestType_STANDARD;
-
-                        ::rtl::Reference< ::comphelper::DocPasswordRequest > pPasswordRequest( new ::comphelper::DocPasswordRequest( eType, ::com::sun::star::task::PasswordRequestMode_PASSWORD_CREATE, *(rpURLList->GetObject(0)), ( pCurrentFilter->GetFilterFlags() & SFX_FILTER_PASSWORDTOMODIFY ) != 0 ) );
-
-                        uno::Reference< com::sun::star::task::XInteractionRequest > rRequest( pPasswordRequest.get() );
-                        xInteractionHandler->handle( rRequest );
-                        if ( pPasswordRequest->isPassword() )
-                        {
-                            if ( pPasswordRequest->getPassword().getLength() )
-                            {
-                                // TODO/LATER: The filters should show the password dialog themself in future
-                                if ( bMSType )
-                                {
-                                    // all the current MS-filters use MSCodec_Std97 implementation
-                                    uno::Sequence< sal_Int8 > aUniqueID = ::comphelper::DocPasswordHelper::GenerateRandomByteSequence( 16 );
-                                    uno::Sequence< sal_Int8 > aEncryptionKey = ::comphelper::DocPasswordHelper::GenerateStd97Key( pPasswordRequest->getPassword(), aUniqueID );
-
-                                    if ( aEncryptionKey.getLength() )
-                                    {
-                                        ::comphelper::SequenceAsHashMap aHashData;
-                                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97EncryptionKey" ) ) ] <<= aEncryptionKey;
-                                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97UniqueID" ) ) ] <<= aUniqueID;
-
-                                        rpSet->Put( SfxUnoAnyItem( SID_ENCRYPTIONDATA, uno::makeAny( aHashData.getAsConstNamedValueList() ) ) );
-                                    }
-                                    else
-                                        return ERRCODE_IO_NOTSUPPORTED;
-                                }
-                                else
-                                {
-                                    rpSet->Put( SfxUnoAnyItem( SID_ENCRYPTIONDATA, uno::makeAny( ::comphelper::OStorageHelper::CreatePackageEncryptionData( pPasswordRequest->getPassword() ) ) ) );
-                                }
-                            }
-
-                            if ( pPasswordRequest->getRecommendReadOnly() )
-                                rpSet->Put( SfxBoolItem( SID_RECOMMENDREADONLY, sal_True ) );
-
-                            if ( bMSType )
-                            {
-                                // the empty password has 0 as Hash
-                                sal_Int32 nHash = SfxMedium::CreatePasswordToModifyHash( pPasswordRequest->getPasswordToModify(), ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.TextDocument" ) ).equals( pCurrentFilter->GetServiceName() ) );
-                                if ( nHash )
-                                    rpSet->Put( SfxUnoAnyItem( SID_MODIFYPASSWORDINFO, uno::makeAny( nHash ) ) );
-                            }
-                            else
-                            {
-                                uno::Sequence< beans::PropertyValue > aModifyPasswordInfo = ::comphelper::DocPasswordHelper::GenerateNewModifyPasswordInfo( pPasswordRequest->getPasswordToModify() );
-                                if ( aModifyPasswordInfo.getLength() )
-                                    rpSet->Put( SfxUnoAnyItem( SID_MODIFYPASSWORDINFO, uno::makeAny( aModifyPasswordInfo ) ) );
-                            }
-                        }
-                        else
-                            return ERRCODE_ABORT;
-                    }
+                    rtl::OUString aDocName(*(rpURLList->GetObject(0)));
+                    ErrCode errCode = RequestPassword(pCurrentFilter, aDocName, rpSet);
+                    if (errCode != ERRCODE_NONE)
+                        return errCode;
                 }
             }
             catch( IllegalArgumentException ){}
@@ -2778,6 +2719,73 @@ ErrCode FileOpenDialog_Impl( sal_Int64 nFlags,
     return nRet;
 }
 
+ErrCode RequestPassword(const SfxFilter* pCurrentFilter, rtl::OUString& aURL, SfxItemSet* pSet)
+{
+    uno::Reference < ::com::sun::star::task::XInteractionHandler > xInteractionHandler( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.uui.UUIInteractionHandler"))), UNO_QUERY );
+
+    if( xInteractionHandler.is() )
+    {
+        // TODO: need a save way to distinguish MS filters from other filters
+        // for now MS-filters are the only alien filters that support encryption
+        bool bMSType = !pCurrentFilter->IsOwnFormat();
+        ::comphelper::DocPasswordRequestType eType = bMSType ?
+            ::comphelper::DocPasswordRequestType_MS :
+            ::comphelper::DocPasswordRequestType_STANDARD;
+
+        ::rtl::Reference< ::comphelper::DocPasswordRequest > pPasswordRequest( new ::comphelper::DocPasswordRequest( eType, ::com::sun::star::task::PasswordRequestMode_PASSWORD_CREATE, aURL, ( pCurrentFilter->GetFilterFlags() & SFX_FILTER_PASSWORDTOMODIFY ) != 0 ) );
+
+        uno::Reference< com::sun::star::task::XInteractionRequest > rRequest( pPasswordRequest.get() );
+        xInteractionHandler->handle( rRequest );
+        if ( pPasswordRequest->isPassword() )
+        {
+            if ( pPasswordRequest->getPassword().getLength() )
+            {
+                // TODO/LATER: The filters should show the password dialog themself in future
+                if ( bMSType )
+                {
+                    // all the current MS-filters use MSCodec_Std97 implementation
+                    uno::Sequence< sal_Int8 > aUniqueID = ::comphelper::DocPasswordHelper::GenerateRandomByteSequence( 16 );
+                    uno::Sequence< sal_Int8 > aEncryptionKey = ::comphelper::DocPasswordHelper::GenerateStd97Key( pPasswordRequest->getPassword(), aUniqueID );
+
+                    if ( aEncryptionKey.getLength() )
+                    {
+                        ::comphelper::SequenceAsHashMap aHashData;
+                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97EncryptionKey" ) ) ] <<= aEncryptionKey;
+                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97UniqueID" ) ) ] <<= aUniqueID;
+
+                        pSet->Put( SfxUnoAnyItem( SID_ENCRYPTIONDATA, uno::makeAny( aHashData.getAsConstNamedValueList() ) ) );
+                    }
+                    else
+                        return ERRCODE_IO_NOTSUPPORTED;
+                }
+                else
+                {
+                    pSet->Put( SfxUnoAnyItem( SID_ENCRYPTIONDATA, uno::makeAny( ::comphelper::OStorageHelper::CreatePackageEncryptionData( pPasswordRequest->getPassword() ) ) ) );
+                }
+            }
+
+            if ( pPasswordRequest->getRecommendReadOnly() )
+                pSet->Put( SfxBoolItem( SID_RECOMMENDREADONLY, sal_True ) );
+
+            if ( bMSType )
+            {
+                // the empty password has 0 as Hash
+                sal_Int32 nHash = SfxMedium::CreatePasswordToModifyHash( pPasswordRequest->getPasswordToModify(), ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.TextDocument" ) ).equals( pCurrentFilter->GetServiceName() ) );
+                if ( nHash )
+                    pSet->Put( SfxUnoAnyItem( SID_MODIFYPASSWORDINFO, uno::makeAny( nHash ) ) );
+            }
+            else
+            {
+                uno::Sequence< beans::PropertyValue > aModifyPasswordInfo = ::comphelper::DocPasswordHelper::GenerateNewModifyPasswordInfo( pPasswordRequest->getPasswordToModify() );
+                if ( aModifyPasswordInfo.getLength() )
+                    pSet->Put( SfxUnoAnyItem( SID_MODIFYPASSWORDINFO, uno::makeAny( aModifyPasswordInfo ) ) );
+            }
+        }
+        else
+            return ERRCODE_ABORT;
+    }
+    return ERRCODE_NONE;
+}
 
 // ------------------------------------------------------------------------
 String EncodeSpaces_Impl( const String& rSource )
