@@ -59,11 +59,8 @@
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
 
-//using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::style;
-//using namespace ::com::sun::star::container;
-//using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::text;
 using namespace ::xmloff::token;
 
@@ -72,7 +69,7 @@ using namespace ::xmloff::token;
 
 // ---------------------------------------------------------------------------
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_HoriPos_Enum[] =
+SvXMLEnumMapEntry const pXML_HoriPos_Enum[] =
 {
     { XML_FROM_LEFT,		HoriOrientation::NONE	},
     { XML_FROM_INSIDE,		HoriOrientation::NONE	},	// import only
@@ -84,7 +81,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_HoriPos_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_HoriPosMirrored_Enum[] =
+SvXMLEnumMapEntry const pXML_HoriPosMirrored_Enum[] =
 {
     { XML_FROM_INSIDE,		HoriOrientation::NONE	},
     { XML_INSIDE,			HoriOrientation::LEFT	},
@@ -93,7 +90,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_HoriPosMirrored_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_HoriRel_Enum[] =
+SvXMLEnumMapEntry const pXML_HoriRel_Enum[] =
 {
     { XML_PARAGRAPH,			RelOrientation::FRAME	},
     { XML_PARAGRAPH_CONTENT,	RelOrientation::PRINT_AREA	},
@@ -111,7 +108,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_HoriRel_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_HoriRelFrame_Enum[] =
+SvXMLEnumMapEntry const pXML_HoriRelFrame_Enum[] =
 {
     { XML_FRAME,				RelOrientation::FRAME	},
     { XML_FRAME_CONTENT,		RelOrientation::PRINT_AREA	},
@@ -125,7 +122,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_HoriRelFrame_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_HoriMirror_Enum[] =
+SvXMLEnumMapEntry const pXML_HoriMirror_Enum[] =
 {
     { XML_FROM_LEFT,		sal_False	},
     { XML_FROM_INSIDE,		sal_True	},
@@ -137,7 +134,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_HoriMirror_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertPos_Enum[] =
+SvXMLEnumMapEntry const pXML_VertPos_Enum[] =
 {
     { XML_FROM_TOP,		    VertOrientation::NONE		},
     { XML_TOP,				VertOrientation::TOP		},
@@ -153,7 +150,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VertPos_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertPosAtChar_Enum[] =
+SvXMLEnumMapEntry const pXML_VertPosAtChar_Enum[] =
 {
     { XML_FROM_TOP,		    VertOrientation::NONE		},
     { XML_TOP,				VertOrientation::TOP		},
@@ -168,7 +165,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VertPosAtChar_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertRel_Enum[] =
+SvXMLEnumMapEntry const pXML_VertRel_Enum[] =
 {
     { XML_PARAGRAPH,			RelOrientation::FRAME	},
     { XML_PARAGRAPH_CONTENT,	RelOrientation::PRINT_AREA	},
@@ -183,7 +180,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VertRel_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertRelPage_Enum[] =
+SvXMLEnumMapEntry const pXML_VertRelPage_Enum[] =
 {
     { XML_PAGE,			RelOrientation::FRAME	},
     { XML_PAGE_CONTENT,	RelOrientation::PRINT_AREA	},
@@ -192,14 +189,14 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VertRelPage_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertRelFrame_Enum[] =
+SvXMLEnumMapEntry const pXML_VertRelFrame_Enum[] =
 {
     { XML_FRAME,			RelOrientation::FRAME	},
     { XML_FRAME_CONTENT,	RelOrientation::PRINT_AREA	},
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VertRelAsChar_Enum[] =
+SvXMLEnumMapEntry const pXML_VertRelAsChar_Enum[] =
 {
     { XML_BASELINE,		VertOrientation::TOP		},
     { XML_BASELINE,		VertOrientation::CENTER		},	// export only
@@ -213,7 +210,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VertRelAsChar_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_RubyAdjust_Enum[] =
+SvXMLEnumMapEntry const pXML_RubyAdjust_Enum[] =
 {
     { XML_LEFT,				    RubyAdjust_LEFT },
     { XML_CENTER,				RubyAdjust_CENTER },
@@ -223,7 +220,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_RubyAdjust_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_FontRelief_Enum[] =
+SvXMLEnumMapEntry const pXML_FontRelief_Enum[] =
 {
     { XML_NONE,				FontRelief::NONE		},
     { XML_ENGRAVED,			FontRelief::ENGRAVED	},
@@ -231,7 +228,7 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_FontRelief_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_VerticalAlign_Enum[] =
+SvXMLEnumMapEntry const pXML_VerticalAlign_Enum[] =
 {
     { XML_TOP,			ParagraphVertAlign::TOP		},
     { XML_MIDDLE,		ParagraphVertAlign::CENTER	},
@@ -242,14 +239,12 @@ SvXMLEnumMapEntry __READONLY_DATA pXML_VerticalAlign_Enum[] =
 };
 
 // OD 2004-05-05 #i28701#
-SvXMLEnumMapEntry __READONLY_DATA pXML_WrapInfluenceOnPosition_Enum[] =
+SvXMLEnumMapEntry const pXML_WrapInfluenceOnPosition_Enum[] =
 {
-    // --> OD 2004-10-18 #i35017# - tokens have been renamed and
-    // <XML_ITERATIVE> has been added
+    // Tokens have been renamed and <XML_ITERATIVE> has been added (#i35017#)
     { XML_ONCE_SUCCESSIVE, WrapInfluenceOnPosition::ONCE_SUCCESSIVE },
     { XML_ONCE_CONCURRENT, WrapInfluenceOnPosition::ONCE_CONCURRENT },
     { XML_ITERATIVE,       WrapInfluenceOnPosition::ITERATIVE },
-    // <--
     { XML_TOKEN_INVALID, 0 }
 };
 
@@ -472,7 +467,7 @@ XMLParagraphOnlyPropHdl_Impl::~XMLParagraphOnlyPropHdl_Impl()
 
 // ---------------------------------------------------------------------------
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Wrap_Enum[] =
+SvXMLEnumMapEntry const pXML_Wrap_Enum[] =
 {
     { XML_NONE,		    WrapTextMode_NONE },
     { XML_RUN_THROUGH,	WrapTextMode_THROUGHT },
@@ -619,7 +614,7 @@ XMLFrameProtectPropHdl_Impl::~XMLFrameProtectPropHdl_Impl()
 
 // ---------------------------------------------------------------------------
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Anchor_Enum[] =
+SvXMLEnumMapEntry const pXML_Anchor_Enum[] =
 {
     { XML_CHAR,		    TextContentAnchorType_AT_CHARACTER },
     { XML_PAGE,	        TextContentAnchorType_AT_PAGE },
@@ -854,12 +849,12 @@ sal_Bool XMLGrfMirrorPropHdl_Impl::exportXML(
                rStrExpValue = sVal;
         }
         else if( bHori &&
-                 // --> OD 2005-05-12 #i49139#
-                 // XML_HORIZONTAL_ON_LEFT_PAGES and XML_HORIZONTAL_ON_RIGHT_PAGES
-                 // are replaced by XML_HORIZONTAL_ON_EVEN and XML_HORIZONTAL_ON_ODD.
+                 /* XML_HORIZONTAL_ON_LEFT_PAGES and XML_HORIZONTAL_ON_RIGHT_PAGES
+                    are replaced by XML_HORIZONTAL_ON_EVEN and XML_HORIZONTAL_ON_ODD.
+                    (#i49139#)
+                 */
                  ( IsXMLToken( rStrExpValue, XML_HORIZONTAL_ON_EVEN ) ||
                    IsXMLToken( rStrExpValue, XML_HORIZONTAL_ON_ODD ) ))
-                 // <--
         {
             rStrExpValue = GetXMLToken( XML_HORIZONTAL );
         }
@@ -887,7 +882,7 @@ XMLGrfMirrorPropHdl_Impl::~XMLGrfMirrorPropHdl_Impl()
 
 // ---------------------------------------------------------------------------
 
-SvXMLEnumMapEntry __READONLY_DATA pXML_Emphasize_Enum[] =
+SvXMLEnumMapEntry const pXML_Emphasize_Enum[] =
 {
     { XML_NONE,	    FontEmphasis::NONE },
     { XML_DOT,		FontEmphasis::DOT_ABOVE },
@@ -1036,7 +1031,8 @@ sal_Bool XMLTextCombineCharPropHdl_Impl::exportXML(
 {
     rValue >>= rStrExpValue;
 
-    return sal_True;
+    // #i114107# attribute of type "character": export only if length is 1
+    return (1 == rStrExpValue.getLength())  ? sal_True : sal_False;
 }
 
 XMLTextCombineCharPropHdl_Impl::~XMLTextCombineCharPropHdl_Impl()
@@ -1342,16 +1338,12 @@ const XMLPropertyHandler *XMLTextPropertyHandlerFactory_Impl::GetPropertyHandler
         pHdl = new XMLGrfMirrorPropHdl_Impl( XML_VERTICAL, sal_False );
         break;
     case XML_TYPE_TEXT_MIRROR_HORIZONTAL_LEFT:
-        // --> OD 2005-05-12 #i49139#
-        // XML_HORIZONTAL_ON_LEFT_PAGES is replaced by XML_HORIZONTAL_ON_EVEN.
+        // XML_HORIZONTAL_ON_LEFT_PAGES is replaced by XML_HORIZONTAL_ON_EVEN. (#i49139#)
         pHdl = new XMLGrfMirrorPropHdl_Impl( XML_HORIZONTAL_ON_EVEN, sal_True );
-        // <--
         break;
     case XML_TYPE_TEXT_MIRROR_HORIZONTAL_RIGHT:
-        // --> OD 2005-05-12 #i49139#
-        // XML_HORIZONTAL_ON_RIGHT_PAGES is replaced by XML_HORIZONTAL_ON_ODD.
+        // XML_HORIZONTAL_ON_RIGHT_PAGES is replaced by XML_HORIZONTAL_ON_ODD. (#i49139#)
         pHdl = new XMLGrfMirrorPropHdl_Impl( XML_HORIZONTAL_ON_ODD, sal_True );
-        // <--
         break;
     case XML_TYPE_TEXT_CLIP:
         pHdl = new XMLClipPropertyHandler( sal_False );
